@@ -114,42 +114,47 @@ def _files(source):
     else :
          yield open(source, 'rb')
 
-def put(source, dest, tar=False, *args, **kwargs):a
+def put(source, dest, tar=False, *args, **kwargs):
     result = None
+    sourcepath = source
+    destpath = dest
     if tar:
         tmp = uuid.uuid1()
-        tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
-        tar(source, tmpsourcepath)
+        sourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
+        tar(source, sourcepath)
 
     with settings(warn_only=True):
-        result = api.put(tmpsourcepath, dest, *args, **kwargs)
+        result = api.put(sourcepath, dest, *args, **kwargs)
 
     if tar:
-        tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
-        untar(tmpdestpath, dest, local=False)
+        destpath = "%s/%s.tar.gz" % (dest, tmp)
+        untar(destpath, dest, local=False)
 
-        local('rm -fr %s' % tmpsourcepath)
-        run('rm -fr %s' % tmpdestpath)
+        local('rm -fr %s' % sourcepath)
+        run('rm -fr %s' % destpath)
 
     return result
 
 
 def get(source, dest, tar=False, *args, **kwargs):
     result = None
+    sourcepath = source
+    destpath = dest
+ 
     if tar:
         tmp = uuid.uuid1()
-        tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
-        tar(source, tmpsourcepath, local_use=False)
+        sourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
+        tar(source, sourcepath, local_use=False)
 
     with settings(warn_only=True):
-        result = api.get(tmpsourcepath, dest, *args, **kwargs)
+        result = api.get(sourcepath, dest, *args, **kwargs)
 
     if tar:
-        tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
-        untar(tmpdestpath, dest)
+        destpath = "%s/%s.tar.gz" % (dest, tmp)
+        untar(destpath, dest)
 
-        local('rm -fr %s' % tmpdestpath)
-        run('rm -fr %s' % tmpsourcepath)
+        local('rm -fr %s' % destpath)
+        run('rm -fr %s' % sourcepath)
     return result
 
 def firewall(flag=True):
